package com.mycompany.marketing;

/*
 *-------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * WebSphere Commerce
 *
 * (c) Copyright International Business Machines Corporation.
 *     2006
 *     All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the US Copyright Office.
 *-------------------------------------------------------------------
 */
import java.util.Date;
import java.util.List;
import java.util.logging.Logger;
import com.ibm.commerce.foundation.common.exception.ApplicationError;
import com.ibm.commerce.foundation.common.util.logging.LoggingHelper;
import com.ibm.commerce.foundation.common.util.sdo.SDODataTypeHelper;
import com.ibm.commerce.foundation.server.services.dataaccess.exception.DataMediatorException;
import com.ibm.commerce.marketing.facade.datatypes.ActivityType;
import com.ibm.commerce.marketing.facade.server.entity.datatypes.Dmactivity;
import com.ibm.commerce.marketing.facade.server.services.dataaccess.bom.mediator.ChangeActivityMediator;
import com.ibm.commerce.marketing.logging.MarketingApplicationMessageKeys;
import com.mycompany.marketing.logging.MyMarketingMessageKeys;

/**
* This class extends ChangeActivityMediator and rewrites validateCreate and validateChange methods for validation of 
* startdate and enddate of activities. Ensure that the end date is at least 10 days after the start date.
*/

public class MyChangeActivityMediator extends ChangeActivityMediator {
	private static final String COPYRIGHT = com.ibm.commerce.copyright.IBMCopyright.SHORT_COPYRIGHT;

	private static final String CLASSNAME = MyChangeActivityMediator.class
			.getName();

	private static final Logger LOGGER = LoggingHelper
			.getLogger(MyChangeActivityMediator.class);
        /** 
          * This method is for verifying that the end date is at least 10 days after the start date. 
          *This method firstly call supper.validateCreate(),then do validation for statdate and enddate.  
          * If validation fails, a validation error message will be returned.
          * @return validationErrors
          */

       public List validateCreate(Object aNoun) throws DataMediatorException {
		final String METHODNAME = "validateCreate";
		if (LoggingHelper.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.entering(CLASSNAME, METHODNAME, new Object[] { aNoun });
		}
		ActivityType activity = (ActivityType) aNoun;
		try {
			List validationErrors = super.validateCreate(aNoun);
			// check that the end date is after the start date
			Date startDate = null;
			Date endDate = null;

			startDate = SDODataTypeHelper.getXMLDateTime(activity
					.getStartDate());
			endDate = SDODataTypeHelper.getXMLDateTime(activity.getEndDate());
			if (startDate != null && endDate != null) {
				LOGGER.log(java.util.logging.Level.INFO,
						"** this is validateCreate for startdate enddate **");
				long days = (endDate.getTime() - startDate.getTime()) / 1000 / 3600 / 24;
				LOGGER.log(java.util.logging.Level.INFO, String.valueOf(days));
				if (days < 10) {
					ApplicationError validateError = new ApplicationError(
							ApplicationError.TYPE_GENERIC_ERROR,
							MyMarketingMessageKeys._APP_Marketingext_END_DATE_AFTER_START_DATE_Over10Days,
							null, LOGGER.getResourceBundleName());
					validationErrors.add(validateError);
				}
			}
			if (LoggingHelper.isEntryExitTraceEnabled(LOGGER)) {
				LOGGER.exiting(CLASSNAME, METHODNAME, validationErrors);
			}
			return validationErrors;
		} catch (DataMediatorException dme) {
			throw dme;
		}
	}

   /** 
     * This method is for verifying the difference of more than 10 day between startdate and enddate. 
     *This method firstly calls supper.validateChange(),then does the validation for statdate and enddate.  
     * If the validation fail, validation error message will return.
     * @return validationErrors
     */

	public List validateChange(Object aNoun) throws DataMediatorException {
		final String METHODNAME = "validateChange";
		try {
			List validationErrors = super.validateChange(aNoun);
			Dmactivity existingActivity = (Dmactivity) findPhysicalEntity(aNoun);
			ActivityType activity = (ActivityType) aNoun;
			Date startDate = null;
			Date endDate = null;
			String enddatestring = "enddate";
			if (activity.getStartDate() != null) {
				startDate = SDODataTypeHelper.getXMLDateTime(activity
						.getStartDate());
				if (startDate == null) {
					ApplicationError validateError = new ApplicationError(
							ApplicationError.TYPE_GENERIC_ERROR,
							MarketingApplicationMessageKeys._APP_CAMPAIGN_INVALID_START_DATE,
							null, LOGGER.getResourceBundleName());
					validationErrors.add(validateError);
				}
			} else {
				startDate = existingActivity.getStartdate();
			}
			if (activity.getEndDate() != null) {
				endDate = SDODataTypeHelper.getXMLDateTime(activity
						.getEndDate());
				if (endDate == null) {
					ApplicationError validateError = new ApplicationError(
							ApplicationError.TYPE_GENERIC_ERROR,
							MarketingApplicationMessageKeys._APP_CAMPAIGN_INVALID_END_DATE,
							null, LOGGER.getResourceBundleName());
					validationErrors.add(validateError);
				}
			} else {
				endDate = existingActivity.getEnddate();
			}
			// check that the end date is after the start date
			if (startDate != null && endDate != null) {
				LOGGER.log(java.util.logging.Level.INFO,
						"** this is validateChange for startdate enddate **");
				long days = (endDate.getTime() - startDate.getTime()) / 1000 / 3600 / 24;
				LOGGER.log(java.util.logging.Level.INFO, String.valueOf(days));
				if (days < 10) {
					ApplicationError validateError = new ApplicationError(
							ApplicationError.TYPE_GENERIC_ERROR,
							MyMarketingMessageKeys._APP_Marketingext_END_DATE_AFTER_START_DATE_Over10Days,
							null, LOGGER.getResourceBundleName());
					validationErrors.add(validateError);
				}
			}
			if (LoggingHelper.isEntryExitTraceEnabled(LOGGER)) {
				LOGGER.exiting(CLASSNAME, METHODNAME, validationErrors);
			}
			return validationErrors;
		} catch (DataMediatorException dme) {
			throw dme;
		}
	}}
